@@ -1,7 +1,10 @@
 import httplib
 import socket
+from django.conf import settings
+from django.utils import simplejson as json
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
+VERSION = map(int, __version__.split('.'))
 
 class AnnounceClient(object):
     """
@@ -10,10 +13,7 @@ class AnnounceClient(object):
     for general use (or maybe for another python web framework)
     """
     def __init__(self):
-        from django.conf import settings
-        from django.utils import simplejson as json
         self.base_url = getattr(settings, 'ANNOUNCE_API_ADDR', 'localhost:6600')
-        self.json = json
 
     def _do_request(self, method, path, *args, **kwargs):
         # A generic wrapper around httplib.
@@ -38,7 +38,7 @@ class AnnounceClient(object):
         if not response or response.status > 399:
             return None
         try:
-            resp = self.json.loads(response.read())
+            resp = json.loads(response.read())
         except ValueError:
             return None
         if resp:
@@ -74,7 +74,7 @@ class AnnounceClient(object):
         """
         path = '/emit/user/%s/%s' % (user_id, channel)
         headers = {'Content-Type' : 'application/json'}
-        data = self.json.dumps(data)
+        data = json.dumps(data)
         response = self._do_request('POST', path, data, headers)
         response.read()
 
@@ -85,7 +85,7 @@ class AnnounceClient(object):
         """
         path = '/emit/group/%s/%s' % (group_name, channel)
         headers = {'Content-Type' : 'application/json'}
-        data = self.json.dumps(data)
+        data = json.dumps(data)
         response = self._do_request('POST', path, data, headers)
         response.read()
 
@@ -96,7 +96,7 @@ class AnnounceClient(object):
         """
         path = '/emit/room/%s' % (channel)
         headers = {'Content-Type' : 'application/json'}
-        data = self.json.dumps(data)
+        data = json.dumps(data)
         response = self._do_request('POST', path, data, headers)
         response.read()
 
@@ -106,7 +106,7 @@ class AnnounceClient(object):
         """
         path = '/emit/broadcast/%s' % (channel)
         headers = {'Content-Type' : 'application/json'}
-        data = self.json.dumps(data)
+        data = json.dumps(data)
         response = self._do_request('POST', path, data, headers)
         response.read()
 
@@ -119,7 +119,7 @@ class AnnounceClient(object):
         response = self._do_request('GET', path)
         data = response.read()
         try:
-            return self.json.loads(data)
+            return json.loads(data)
         except ValueError:
             return None
 
